==> App-powerdiff-v1.0.0.tar.gz: App-powerdiff-v1.0.0/lib/App/powerdiff.pm <==
package App::powerdiff;
use 5.010001;
use warnings;
use strict;

our $VERSION = 'v1.0.0';


1;
__END__

=encoding utf8

=head1 NAME

App::powerdiff - Prepare a diff between two given directories


=head1 SYNOPSIS

  powerdiff --help


=head1 DESCRIPTION

See L<powerdiff>.


=head1 SUPPORT

=head2 Bugs / Feature Requests

Please report any bugs or feature requests through the issue tracker
at L<https://github.com/powerman/powerdiff/issues>.
You will be notified automatically of any progress on your issue.

=head2 Source Code

This is open source software. The code repository is available for
public review and contribution under the terms of the license.
Feel free to fork the repository and submit pull requests.

L<https://github.com/powerman/powerdiff>

    git clone https://github.com/powerman/powerdiff.git

=head2 Resources

=over

=item * MetaCPAN Search

L<https://metacpan.org/search?q=App-powerdiff>

=item * CPAN Ratings

L<http://cpanratings.perl.org/dist/App-powerdiff>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/App-powerdiff>

=item * CPAN Testers Matrix

L<http://matrix.cpantesters.org/?dist=App-powerdiff>

=item * CPANTS: A CPAN Testing Service (Kwalitee)

L<http://cpants.cpanauthors.org/dist/App-powerdiff>

=back


=head1 AUTHOR

Alex Efros E<lt>powerman@cpan.orgE<gt>


=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2009-2013 by Alex Efros E<lt>powerman@cpan.orgE<gt>.

This is free software, licensed under:

  The MIT (X11) License


=head1 SEE ALSO


=cut

==> App-powerdiff-v1.0.1.tar.gz: App-powerdiff-v1.0.1/lib/App/powerdiff.pm <==
package App::powerdiff;
use 5.010001;
use warnings;
use strict;
use utf8;
use Carp;

our $VERSION = 'v1.0.1';


1; # Magic true value required at end of module
__END__

=encoding utf8

=head1 NAME

App::powerdiff - Prepare a diff between two given directories


=head1 VERSION

This document describes App::powerdiff version v1.0.1


=head1 SYNOPSIS

    powerdiff --help


=head1 DESCRIPTION

See L<powerdiff>.


=head1 SUPPORT

=head2 Bugs / Feature Requests

Please report any bugs or feature requests through the issue tracker
at L<https://github.com/powerman/powerdiff/issues>.
You will be notified automatically of any progress on your issue.

=head2 Source Code

This is open source software. The code repository is available for
public review and contribution under the terms of the license.
Feel free to fork the repository and submit pull requests.

L<https://github.com/powerman/powerdiff>

    git clone https://github.com/powerman/powerdiff.git

=head2 Resources

=over

=item * MetaCPAN Search

L<https://metacpan.org/search?q=App-powerdiff>

=item * CPAN Ratings

L<http://cpanratings.perl.org/dist/App-powerdiff>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/App-powerdiff>

=item * CPAN Testers Matrix

L<http://matrix.cpantesters.org/?dist=App-powerdiff>

=item * CPANTS: A CPAN Testing Service (Kwalitee)

L<http://cpants.cpanauthors.org/dist/App-powerdiff>

=back


=head1 AUTHOR

Alex Efros E<lt>powerman@cpan.orgE<gt>


=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2009- by Alex Efros E<lt>powerman@cpan.orgE<gt>.

This is free software, licensed under:

  The MIT (X11) License


=cut
